@@ -1122,3 +1122,179 @@ dsadmin.perm_delete <- function(opal, subject, type = "user") {
     ignore <- opal.delete(opal, "system", "permissions", "datashield", query = list(principal = subject[i], type = toupper(type)))
   }
 }
+
+#' Get DataSHIELD activity
+#'
+#' Get the recorded DataSHIELD session metrics. 
+#'
+#' @param opal Opal connection object.
+#' @param user Optional user name.
+#' @param profile Optional profile name.
+#' @param from Optional start date.
+#' @param to Optional end date.
+#' @param df Return a data.frame (default is TRUE)
+#' @examples
+#' \dontrun{
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
+#' # all sessions metrics
+#' dsadmin.activity(o)
+#' # user and profile specific session metrics
+#' dsadmin.activity(o, user = 'dsuser', profile = 'default')
+#' # user sessions in a time range
+#' dsadmin.activity(o, user = "dsuser", from = "2022-07-01", to = "2023-01-01")
+#' opal.logout(o)
+#' }
+#' @export
+dsadmin.activity <- function(opal, user = NULL, profile = NULL, from = NULL, to = NULL, df = TRUE) {
+  if (opal.version_compare(opal,"4.6")<0) {
+    stop("DataSHIELD activity requires Opal 4.6 or higher.")
+  }
+  dtos <- opal.get(opal, "service", "r", "activity", query = list(context = "DataSHIELD", user = user, profile = profile, from = from, to = to))
+  if (df) {
+    n <- length(dtos)
+    profile <- rep(NA, n)
+    user <- rep(NA, n)
+    created <- rep(NA, n)
+    updated <- rep(NA, n)
+    executionTimeMillis <- rep(NA, n)
+    if (n>0) {
+      for (i in 1:n) {
+        profile[i] <- dtos[[i]]$profile
+        user[i] <- dtos[[i]]$user
+        created[i] <- dtos[[i]]$createdDate
+        updated[i] <- dtos[[i]]$updatedDate
+        executionTimeMillis[i] <- dtos[[i]]$executionTimeMillis
+      }
+    }
+    data.frame(profile = profile, user = user, created = created, updated = updated, executionTimeMillis = executionTimeMillis, stringsAsFactors = FALSE)
+  } else {
+    dtos
+  }
+}
+
+#' Get DataSHIELD activity summary
+#'
+#' Get the recorded DataSHIELD session metrics, grouped by profile and user. 
+#'
+#' @param opal Opal connection object.
+#' @param user Optional user name.
+#' @param profile Optional profile name.
+#' @param from Optional start date.
+#' @param to Optional end date.
+#' @param df Return a data.frame (default is TRUE)
+#' @examples
+#' \dontrun{
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
+#' # all sessions metrics
+#' dsadmin.activity_summary(o)
+#' # user and profile specific session metrics
+#' dsadmin.activity_summary(o, user = 'dsuser', profile = 'default')
+#' # user sessions in a time range
+#' dsadmin.activity_summary(o, user = "dsuser", from = "2022-07-01", to = "2023-01-01")
+#' opal.logout(o)
+#' }
+#' @export
+dsadmin.activity_summary <- function(opal, user = NULL, profile = NULL, from = NULL, to = NULL, df = TRUE) {
+  if (opal.version_compare(opal,"4.6")<0) {
+    stop("DataSHIELD activity requires Opal 4.6 or higher.")
+  }
+  dtos <- opal.get(opal, "service", "r", "activity", "_summary",  query = list(context = "DataSHIELD", user = user, profile = profile, from = from, to = to))
+  if (df) {
+    n <- length(dtos)
+    profile <- rep(NA, n)
+    user <- rep(NA, n)
+    start <- rep(NA, n)
+    end <- rep(NA, n)
+    executionTimeMillis <- rep(NA, n)
+    sessionsCount <- rep(NA, n)
+    if (n>0) {
+      for (i in 1:n) {
+        profile[i] <- dtos[[i]]$profile
+        user[i] <- dtos[[i]]$user
+        start[i] <- dtos[[i]]$start
+        end[i] <- dtos[[i]]$end
+        executionTimeMillis[i] <- dtos[[i]]$executionTimeMillis
+        sessionsCount[i] <- dtos[[i]]$sessionsCount
+      }
+    }
+    data.frame(profile = profile, user = user, start = start, end = end, executionTimeMillis = executionTimeMillis, sessionsCount = sessionsCount, stringsAsFactors = FALSE)
+  } else {
+    dtos
+  }
+}
+
+#' Get DataSHIELD logs
+#' 
+#' The DataSHIELD log is structured as follows:
+#' 
+#' \strong{Common fields}
+#' \itemize{
+#'   \item timestamp: when action is logged
+#'   \item version: not used
+#'   \item message: human readable message
+#'   \item logger_name: name of the log channel
+#'   \item thread_name: java thread name
+#'   \item level: log level (TRACE, DEBUG, INFO, WARN, ERROR)
+#'   \item level_value: log level numeric value
+#'   \item ip: ip origin of the request, when available
+#'   \item ds_id: unique DS session ID
+#'   \item ds_profile: DS profile name (available after the R server session is created, can be after authentication)
+#'   \item username: DS user name
+#'   \item r_duration: time spent by the remote R server action (all except PARSE)
+#'   \item r_size: R result serialized object size in bytes
+#'   \item ds_action: DS operation (OPEN, CLOSE, PARSE, ASSIGN, AGGREGATE, LS, RM, WS_SAVE, WS_RESTORE)
+#' }
+#' 
+#' \strong{DS operations fields}
+#' \itemize{
+#'   \item OPEN: DS session opened (note: happens after successful authentication as R server session creation is deferred)
+#'   \item CLOSE: DS session closed
+#'   \item PARSE: R expression parsed
+#'   \itemize{
+#'     \item ds_map: DS function mappings used in the R parser, separated by semicolons when several functions are called
+#'     \item ds_script_in: R script as sent by DS user
+#'     \item ds_script_out: R script rewritten by opal, to be evaluated
+#'   }
+#'   \item ASSIGN:
+#'   \itemize{
+#'     \item ds_symbol: assigned symbol name
+#'     \item ds_table: table name that is assigned
+#'     \item ds_resource: resource name that is assigned
+#'     \item ds_eval: assign R expression that is evaluated
+#'   }
+#'   \item AGGREGATE:
+#'   \itemize{
+#'     \item ds_eval: aggregate R expression that is evaluated
+#'   }
+#'   \item LS: R symbols listed
+#'   \item RM: R symbol removed
+#'   \itemize{
+#'     \item ds_symbol: symbol name to remove
+#'   }
+#'   \item WS_SAVE:
+#'   \itemize{
+#'     \item ds_ws: workspace name
+#'   }
+#'   \item WS_RESTORE:
+#'   \itemize{
+#'     \item ds_ws: workspace name
+#'   }
+#' }
+#' 
+#' @param opal Opal connection object.
+#' @param all Get all or only latest log messages.
+#' @examples
+#' \dontrun{
+#' o <- opal.login('administrator','password', url='https://opal-demo.obiba.org')
+#' dsadmin.log(o)
+#' opal.logout(o)
+#' }
+#' @export
+#' @import jsonlite
+dsadmin.log <- function(opal, all = TRUE) {
+  tmp <- tempfile()
+  opal.get(opal, "system", "log", "datashield.log", acceptType = "text/plain", query = list(all = all), outFile = tmp)
+  rval <- jsonlite::stream_in(file(tmp))
+  unlink(tmp)
+  rval
+}
\ No newline at end of file
